@@ -1,7 +1,8 @@
 """Contains exceptions that are raised when errors occur with config directories."""
+from autoconfiguration.exceptions.base_exception import ConfigBaseError
 
 
-class ConfigDirNotFoundError(Exception):
+class ConfigDirNotFoundError(ConfigBaseError):
     """Raised if the configuration directory does not exist."""
 
     def __init__(self, config_dir: str):
