@@ -1,7 +1,8 @@
 """Contains exceptions that are raised when errors occur with config files."""
+from autoconfiguration.exceptions.base_exception import ConfigBaseError
 
 
-class NoConfigFilesFoundError(Exception):
+class NoConfigFilesFoundError(ConfigBaseError):
     """Raised if none of the configuration files exist."""
 
     def __init__(self):
